@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 use base qw(Exporter);
 
-our $VERSION = '1.003007';
+our $VERSION = '1.003010';
 $VERSION = eval $VERSION;
 
 sub _choose_json_module {
@@ -111,7 +111,7 @@ JSON::MaybeXS - Use L<Cpanel::JSON::XS> with a fallback to L<JSON::XS> and L<JSO
 
   my $json_output = encode_json($data_structure);
 
-  my $json = JSON->new;
+  my $json = JSON()->new;
 
   my $json_with_args = JSON::MaybeXS->new(utf8 => 1); # or { utf8 => 1 }
 
@@ -181,12 +181,15 @@ B<only>.
 The C<JSON> constant returns the selected implementation module's name for
 use as a class name - so:
 
-  my $json_obj = JSON->new; # returns a Cpanel::JSON::XS or JSON::PP object
+  my $json_obj = JSON()->new; # returns a Cpanel::JSON::XS or JSON::PP object
 
 and that object can then be used normally:
 
   my $data_structure = $json_obj->decode($json_text); # etc.
 
+The use of parentheses here is optional, and only used as a hint to the reader
+that this use of C<JSON> is a I<subroutine> call, I<not> a class name.
+
 =head2 is_bool
 
   $is_boolean = is_bool($scalar)
@@ -223,8 +226,8 @@ least) the methods C<encode> and C<decode>.
 To include JSON-aware booleans (C<true>, C<false>) in your data, just do:
 
     use JSON::MaybeXS;
-    my $true = JSON->true;
-    my $false = JSON->false;
+    my $true = JSON()->true;
+    my $false = JSON()->false;
 
 =head1 CONVERTING FROM JSON::Any
 
@@ -274,6 +277,23 @@ Alternatively, you can use duck typing:
     use Moose::Util::TypeConstraints 'duck_type';
     is 'json' => ( isa => Object , duck_type([qw/ encode decode /]));
 
+=head1 INSTALLATION
+
+At installation time, F<Makefile.PL> will attempt to determine if you have a
+working compiler available, and therefore whether you are able to run XS code.
+If so, L<Cpanel::JSON::XS> will be added to the prerequisite list, unless
+L<JSON::XS> is already installed at a high enough version. L<JSON::XS> may
+also be upgraded to fix any incompatibility issues.
+
+Because running XS code is not mandatory and L<JSON::PP> (which is in perl
+core) is used as a fallback backend, this module is safe to be used in a suite
+of code that is fatpacked or installed into a restricted-resource environment.
+
+You can also prevent any XS dependencies from being installed by setting
+C<PUREPERL_ONLY=1> in F<Makefile.PL> options (or in the C<PERL_MM_OPT>
+environment variable), or using the C<--pp> or C<--pureperl> flags with the
+L<cpanminus client|cpanm>.
+
 =head1 AUTHOR
 
 mst - Matt S. Trout (cpan:MSTROUT) <mst@shadowcat.co.uk>
